var pipewire_8h =
[
    [ "pw_debug_is_category_enabled", "pipewire_8h.html#acc287aaae982260a49eeac97f27a8227", null ],
    [ "pw_direction_reverse", "pipewire_8h.html#a4efeba27bea1dc8d9188b8e49b3bd1b0", null ],
    [ "pw_fill_remote_properties", "pipewire_8h.html#a8b0b569ab7f3457801c61562340be8f8", null ],
    [ "pw_fill_stream_properties", "pipewire_8h.html#ab6df08f2eaa6273cbaa019115a3f4646", null ],
    [ "pw_get_application_name", "pipewire_8h.html#a7f855ab509d6e01e13cf561968a4d1b6", null ],
    [ "pw_get_client_name", "pipewire_8h.html#a899cef520412dc30503281f0d7f1f38b", null ],
    [ "pw_get_host_name", "pipewire_8h.html#a5cb61aa7df1b5fc780b2df1dd1d576b6", null ],
    [ "pw_get_prgname", "pipewire_8h.html#a4a582dbda1862c28b2eb70f50696cfc3", null ],
    [ "pw_get_spa_dbus", "pipewire_8h.html#a5576e00ff68e70c49126208a243460a3", null ],
    [ "pw_get_support", "pipewire_8h.html#a3a41ee3d8c3c6f8bcec7a01485e85770", null ],
    [ "pw_get_support_factory", "pipewire_8h.html#af2d5f277271ef9f59827ce7ebf0c4378", null ],
    [ "pw_get_support_interface", "pipewire_8h.html#abadaa5454bbccba79adfa316d725e0a2", null ],
    [ "pw_get_user_name", "pipewire_8h.html#a0b5efe6f38693683c07c4495bfcce6c4", null ],
    [ "pw_init", "pipewire_8h.html#a06c879b2d800579f4724109054368d99", null ],
    [ "pw_release_spa_dbus", "pipewire_8h.html#ad76e718e0df792d89e19d6c984762af0", null ]
];